==> FreePastry-1.4.1_01_20050816-source.zip: pastry-1.4.1_01_20050816/src/rice/environment/processing/simple/ProcessingThread.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
/*
 *  Created on Aug 9, 2005
 */
package rice.environment.processing.simple;

/**
 * @version $Id: pretty.settings,v 1.3 2005/03/11 20:22:33 jeffh Exp $
 * @author Jeff Hoye
 */
public class ProcessingThread extends Thread {
  ProcessingQueue queue;

  boolean running = false;

  /**
   * Constructor for ProcessingThread.
   *
   * @param queue DESCRIBE THE PARAMETER
   */
  public ProcessingThread(ProcessingQueue queue) {
    super("Dedicated Processing Thread");
    this.queue = queue;
  }

  /**
   * Main processing method for the ProcessingThread object
   */
  public void run() {
    running = true;
    while (running) {
      ProcessingRequest e = queue.dequeue();
      if (e != null) {
        e.run();
      }
    }
  }

  /**
   * DESCRIBE THE METHOD
   */
  public void destroy() {
    running = false;
  }
}

==> FreePastry-1.4.1_01_20050914-source.zip: pastry-1.4.1_01_20050914/src/rice/environment/processing/simple/ProcessingThread.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
/*
 *  Created on Aug 9, 2005
 */
package rice.environment.processing.simple;

/**
 * @version $Id: pretty.settings,v 1.3 2005/03/11 20:22:33 jeffh Exp $
 * @author Jeff Hoye
 */
public class ProcessingThread extends Thread {
  ProcessingQueue queue;

  boolean running = false;

  /**
   * Constructor for ProcessingThread.
   *
   * @param name DESCRIBE THE PARAMETER
   * @param queue DESCRIBE THE PARAMETER
   */
  public ProcessingThread(String name, ProcessingQueue queue) {
    super(name);
    this.queue = queue;
  }

  /**
   * Main processing method for the ProcessingThread object
   */
  public void run() {
    running = true;
    while (running) {
      ProcessingRequest e = queue.dequeue();
      if (e != null) {
        e.run();
      }
    }
  }

  /**
   * DESCRIBE THE METHOD
   */
  public void destroy() {
    running = false;
  }
}
